@@ -4,6 +4,8 @@ This file contains django context_processors needed by edunext.
 """
 import logging
 
+from ecommerce_extensions.tenant.extra_html import process_html
+from ecommerce_extensions.tenant.extra_scripts import process_scripts
 from ecommerce_extensions.tenant.models import TenantOptions
 
 LOG = logging.getLogger(__name__)
@@ -25,8 +27,12 @@ def theme_options(request):
     except AttributeError:
         site_theme_name = None
 
+    theme_options_values = options.get("THEME_OPTIONS", {})
+
     return {
         "theme_dir_name": site_theme_name,
         "site_configuration": request.site.siteconfiguration,
         "options": options,
+        "scripts": process_scripts(request.path_info, theme_options_values),
+        "html": process_html(request.path_info, theme_options_values)
     }
